@@ -29,6 +29,9 @@ FAILEDOPERATION_ADDRESSENIINFONOTFOUND = 'FailedOperation.AddressEniInfoNotFound
 # 账户余额不足。
 FAILEDOPERATION_BALANCEINSUFFICIENT = 'FailedOperation.BalanceInsufficient'
 
+# 创建云联网失败. 请重试你的请求，如果问题仍然存在，请联系腾讯云客服。
+FAILEDOPERATION_CREATECCNFAILED = 'FailedOperation.CreateCcnFailed'
+
 # 不支持的地域。
 FAILEDOPERATION_INVALIDREGION = 'FailedOperation.InvalidRegion'
 
@@ -95,6 +98,9 @@ INVALIDPARAMETER_ACLTYPEMISMATCH = 'InvalidParameter.AclTypeMismatch'
 # 参数不支持同时指定。
 INVALIDPARAMETER_COEXIST = 'InvalidParameter.Coexist'
 
+# 当前IP已在其他公网IP类型的流量镜像中使用。
+INVALIDPARAMETER_DUPLICATEDLBTRAFFICMIRRORCOLLECTORS = 'InvalidParameter.DuplicatedLbTrafficMirrorCollectors'
+
 # 指定过滤条件不存在。
 INVALIDPARAMETER_FILTERINVALIDKEY = 'InvalidParameter.FilterInvalidKey'
 
@@ -122,6 +128,9 @@ INVALIDPARAMETER_NOTLIST = 'InvalidParameter.NotList'
 # 指定键值不是一个字符串型。
 INVALIDPARAMETER_NOTSTR = 'InvalidParameter.NotStr'
 
+# 当前公网IP所在的地区不支持流量采集。
+INVALIDPARAMETER_UNSUPPORTEDLBTRAFFICMIRRORAZ = 'InvalidParameter.UnsupportedLbTrafficMirrorAz'
+
 # 专线网关跨可用区容灾组不存在。
 INVALIDPARAMETER_VPGHAGROUPNOTFOUND = 'InvalidParameter.VpgHaGroupNotFound'
 
@@ -206,6 +215,12 @@ INVALIDPARAMETERVALUE_DUPLICATEPARA = 'InvalidParameterValue.DuplicatePara'
 # 本端地域和端地域重复。
 INVALIDPARAMETERVALUE_DUPLICATEREGION = 'InvalidParameterValue.DuplicateRegion'
 
+# 当前IP已在其他公网IP类型的流量镜像中使用。
+INVALIDPARAMETERVALUE_DUPLICATEDLBTRAFFICMIRRORCOLLECTORS = 'InvalidParameterValue.DuplicatedLbTrafficMirrorCollectors'
+
+# 当前接收端已在其他的公网IP类型的流量镜像中使用。
+INVALIDPARAMETERVALUE_DUPLICATEDLBTRAFFICMIRRORRECIVERENDPOINT = 'InvalidParameterValue.DuplicatedLbTrafficMirrorReciverEndpoint'
+
 # 值超过上限。
 INVALIDPARAMETERVALUE_EIPBRANDWIDTHOUTINVALID = 'InvalidParameterValue.EIPBrandWidthOutInvalid'
 
@@ -272,6 +287,9 @@ INVALIDPARAMETERVALUE_INVALIDINSTANCESTATE = 'InvalidParameterValue.InvalidInsta
 # 无效的IPv6地址。
 INVALIDPARAMETERVALUE_INVALIDIPV6 = 'InvalidParameterValue.InvalidIpv6'
 
+# 接收端不是一个存在的虚机IP也不是可路由的idc机房IP。
+INVALIDPARAMETERVALUE_INVALIDLBTRAFFICMIRRORRECIVERENDPOINT = 'InvalidParameterValue.InvalidLbTrafficMirrorReciverEndpoint'
+
 # 旧的带宽值无效。
 INVALIDPARAMETERVALUE_INVALIDOLDBANDWIDTH = 'InvalidParameterValue.InvalidOldBandwidth'
 
@@ -305,6 +323,9 @@ INVALIDPARAMETERVALUE_MEMBERAPPROVALAPPLICATIONREJECTED = 'InvalidParameterValue
 # 该请求需要走BPAAS流程服务审批，当前发起审批中。
 INVALIDPARAMETERVALUE_MEMBERAPPROVALAPPLICATIONSTARTED = 'InvalidParameterValue.MemberApprovalApplicationStarted'
 
+# 流量镜像target的内网带宽不足。
+INVALIDPARAMETERVALUE_MIRRORLACKTARGETRESOURCE = 'InvalidParameterValue.MirrorLackTargetResource'
+
 # 缺少绑定的实例。
 INVALIDPARAMETERVALUE_MISSINGASSOCIATEENTITY = 'InvalidParameterValue.MissingAssociateEntity'
 
@@ -353,6 +374,12 @@ INVALIDPARAMETERVALUE_NOTINVPCCIDR = 'InvalidParameterValue.NotInVpcCidr'
 # 不是UTF8编码。
 INVALIDPARAMETERVALUE_NOTUTF8ENCODINGERROR = 'InvalidParameterValue.NotUtf8EncodingError'
 
+# 流量镜像采集对象已经被使用。
+INVALIDPARAMETERVALUE_OBJECTUSEINTRAFFICMIRROR = 'InvalidParameterValue.ObjectUseInTrafficMirror'
+
+# 流量镜像采集的VPC不是当前VPCID。
+INVALIDPARAMETERVALUE_OBJECTVPCNOTCURRENTVPC = 'InvalidParameterValue.ObjectVpcNotCurrentVpc'
+
 # 该操作仅对主网卡支持。
 INVALIDPARAMETERVALUE_ONLYSUPPORTEDFORMASTERNETWORKCARD = 'InvalidParameterValue.OnlySupportedForMasterNetworkCard'
 
@@ -392,6 +419,9 @@ INVALIDPARAMETERVALUE_RESOURCENOTFOUND = 'InvalidParameterValue.ResourceNotFound
 # 该资源不支持此操作。
 INVALIDPARAMETERVALUE_RESOURCENOTSUPPORT = 'InvalidParameterValue.ResourceNotSupport'
 
+# 自定义路由的下一跳参数不正确。
+INVALIDPARAMETERVALUE_ROUTENEXTHOPINVALID = 'InvalidParameterValue.RouteNextHopInvalid'
+
 # 指定的优先级之间冲突或与已存在的优先级冲突。
 INVALIDPARAMETERVALUE_ROUTEPOLICYPRIORITYCONFLICT = 'InvalidParameterValue.RoutePolicyPriorityConflict'
 
@@ -410,6 +440,9 @@ INVALIDPARAMETERVALUE_SUBNETOVERLAP = 'InvalidParameterValue.SubnetOverlap'
 # 子网与辅助Cidr网段重叠。
 INVALIDPARAMETERVALUE_SUBNETOVERLAPASSISTCIDR = 'InvalidParameterValue.SubnetOverlapAssistCidr'
 
+# 子网与自定义路由目的Cidr网段完全重叠。
+INVALIDPARAMETERVALUE_SUBNETOVERLAPROUTE = 'InvalidParameterValue.SubnetOverlapRoute'
+
 # 子网CIDR不合法。
 INVALIDPARAMETERVALUE_SUBNETRANGE = 'InvalidParameterValue.SubnetRange'
 
@@ -470,9 +503,18 @@ INVALIDPARAMETERVALUE_TRAFFICPACKAGERESOURCEIDMALFORMED = 'InvalidParameterValue
 # 该可用区不可用。
 INVALIDPARAMETERVALUE_UNAVAILABLEZONE = 'InvalidParameterValue.UnavailableZone'
 
+# 当前公网IP所在的地区不支持流量采集。
+INVALIDPARAMETERVALUE_UNSUPPORTEDLBTRAFFICMIRRORAZ = 'InvalidParameterValue.UnsupportedLbTrafficMirrorAz'
+
+# 当前流量镜像不支持此操作。
+INVALIDPARAMETERVALUE_UNSUPPORTEDTRAFFICMIRRORACTION = 'InvalidParameterValue.UnsupportedTrafficMirrorAction'
+
 # 目的网段和当前VPC的CIDR冲突。
 INVALIDPARAMETERVALUE_VPCCIDRCONFLICT = 'InvalidParameterValue.VpcCidrConflict'
 
+# 辅助Cidr与自定义子网路由目的Cidr网段完全重叠。
+INVALIDPARAMETERVALUE_VPCCIDROVERLAPROUTE = 'InvalidParameterValue.VpcCidrOverlapRoute'
+
 # 当前功能不支持此专线网关。
 INVALIDPARAMETERVALUE_VPGTYPENOTMATCH = 'InvalidParameterValue.VpgTypeNotMatch'
 
@@ -491,6 +533,9 @@ INVALIDPARAMETERVALUE_VPNCONNCIDRCONFLICT = 'InvalidParameterValue.VpnConnCidrCo
 # VPN通道探测ip冲突。
 INVALIDPARAMETERVALUE_VPNCONNHEALTHCHECKIPCONFLICT = 'InvalidParameterValue.VpnConnHealthCheckIpConflict'
 
+# SPD规则源目IP有重叠。
+INVALIDPARAMETERVALUE_VPNCONNSPDCIDRCONFLICT = 'InvalidParameterValue.VpnConnSpdCidrConflict'
+
 # 参数Zone的值与CDC所在Zone冲突。
 INVALIDPARAMETERVALUE_ZONECONFLICT = 'InvalidParameterValue.ZoneConflict'
 
@@ -794,12 +839,21 @@ UNSUPPORTEDOPERATION_CCNNOTENABLECOMMUNITY = 'UnsupportedOperation.CcnNotEnableC
 # 跨账号场景下不支持自驾云账号实例 关联普通账号云联网。
 UNSUPPORTEDOPERATION_CCNORDINARYACCOUNTREFUSEATTACH = 'UnsupportedOperation.CcnOrdinaryAccountRefuseAttach'
 
+# 当前路由与已有路由的CIDR重叠，仅能开启其中一条路由。
+UNSUPPORTEDOPERATION_CCNROUTECIDROVERLAP = 'UnsupportedOperation.CcnRouteCidrOverlap'
+
 # 指定的路由表不存在。
 UNSUPPORTEDOPERATION_CCNROUTETABLENOTEXIST = 'UnsupportedOperation.CcnRouteTableNotExist'
 
+# 流量计量类型云联网暂不支持跨境
+UNSUPPORTEDOPERATION_CCNTRAFFICMETERINGUNABLECROSSBORDER = 'UnsupportedOperation.CcnTrafficMeteringUnableCrossBorder'
+
 # CDC子网不支持创建非本地网关类型的路由。
 UNSUPPORTEDOPERATION_CDCSUBNETNOTSUPPORTUNLOCALGATEWAY = 'UnsupportedOperation.CdcSubnetNotSupportUnLocalGateway'
 
+# VPG型的CDC网关不存在。
+UNSUPPORTEDOPERATION_CDCVPGNOTEXISTS = 'UnsupportedOperation.CdcVpgNotExists'
+
 # 实例已经和VPC绑定。
 UNSUPPORTEDOPERATION_CLASSICINSTANCEIDALREADYEXISTS = 'UnsupportedOperation.ClassicInstanceIdAlreadyExists'
 
@@ -812,6 +866,12 @@ UNSUPPORTEDOPERATION_CLBPOLICYLIMIT = 'UnsupportedOperation.ClbPolicyLimit'
 # 与该VPC下的TKE容器的网段重叠。
 UNSUPPORTEDOPERATION_CONFLICTWITHDOCKERROUTE = 'UnsupportedOperation.ConflictWithDockerRoute'
 
+# 当前账号不允许创建服务质量：铜云联网。
+UNSUPPORTEDOPERATION_COPPERCCNNOTSUPPORTEDCREATE = 'UnsupportedOperation.CopperCcnNotSupportedCreate'
+
+# 服务质量：铜云联网仅支持创建预付费模式。
+UNSUPPORTEDOPERATION_COPPERCCNSUPPORTEDPREPAID = 'UnsupportedOperation.CopperCcnSupportedPrepaid'
+
 # 当前账号非联通账号。
 UNSUPPORTEDOPERATION_CURRENTACCOUNTISNOTUNICOMACCOUNT = 'UnsupportedOperation.CurrentAccountIsNotUnicomAccount'
 
@@ -824,6 +884,9 @@ UNSUPPORTEDOPERATION_DCGATEWAYNATRULEEXISTS = 'UnsupportedOperation.DCGatewayNat
 # 指定的VPC未发现专线网关。
 UNSUPPORTEDOPERATION_DCGATEWAYSNOTFOUNDINVPC = 'UnsupportedOperation.DcGatewaysNotFoundInVpc'
 
+# 当前专线网关有流日志，不支持删除。
+UNSUPPORTEDOPERATION_DCGHASFLOWLOG = 'UnsupportedOperation.DcgHasFlowLog'
+
 # 禁止删除默认路由表。
 UNSUPPORTEDOPERATION_DELDEFAULTROUTE = 'UnsupportedOperation.DelDefaultRoute'
 
@@ -935,6 +998,9 @@ UNSUPPORTEDOPERATION_INVALIDSTATE = 'UnsupportedOperation.InvalidState'
 # 当前状态不支持发布至云联网，请重试。
 UNSUPPORTEDOPERATION_INVALIDSTATUSNOTIFYCCN = 'UnsupportedOperation.InvalidStatusNotifyCcn'
 
+# 不支持IPV6。
+UNSUPPORTEDOPERATION_IPV6NOTSUPPORT = 'UnsupportedOperation.Ipv6NotSupport'
+
 # 关联当前云联网的实例的账号存在不是金融云账号。
 UNSUPPORTEDOPERATION_ISNOTFINANCEACCOUNT = 'UnsupportedOperation.IsNotFinanceAccount'
 
@@ -1025,6 +1091,9 @@ UNSUPPORTEDOPERATION_NOTSUPPORTZONE = 'UnsupportedOperation.NotSupportZone'
 # 该地址类型不支持释放操作。
 UNSUPPORTEDOPERATION_NOTSUPPORTEDADDRESSIPSCHARGETYPE = 'UnsupportedOperation.NotSupportedAddressIpsChargeType'
 
+# 不支持创建后付费流量计费类型云联网
+UNSUPPORTEDOPERATION_NOTSUPPORTEDCREATETRAFFICMETERINGTYPECCN = 'UnsupportedOperation.NotSupportedCreateTrafficMeteringTypeCcn'
+
 # 此地域没有上线出口二资源，请到北京/广州/南京购买。
 UNSUPPORTEDOPERATION_NOTSUPPORTEDPURCHASECENTEREGRESSRESOURCE = 'UnsupportedOperation.NotSupportedPurchaseCenterEgressResource'
 
@@ -1040,6 +1109,9 @@ UNSUPPORTEDOPERATION_OFFLINECHARGETYPE = 'UnsupportedOperation.OfflineChargeType
 # 仅支持专业版Ckafka。
 UNSUPPORTEDOPERATION_ONLYSUPPORTPROFESSIONKAFKA = 'UnsupportedOperation.OnlySupportProfessionKafka'
 
+# 预付费云联网只支持带宽计量类型
+UNSUPPORTEDOPERATION_PREPAIDCCNONLYSUPPORTBANDWIDTHMETERING = 'UnsupportedOperation.PrepaidCcnOnlySupportBandwidthMetering'
+
 # 预付费云联网只支持地域间限速。
 UNSUPPORTEDOPERATION_PREPAIDCCNONLYSUPPORTINTERREGIONLIMIT = 'UnsupportedOperation.PrepaidCcnOnlySupportInterRegionLimit'
 
@@ -1049,6 +1121,9 @@ UNSUPPORTEDOPERATION_PRIMARYIP = 'UnsupportedOperation.PrimaryIp'
 # 私网NAT网关存在关联规则。
 UNSUPPORTEDOPERATION_PRIVATENATGATEWAYASSOCIATIONEXISTS = 'UnsupportedOperation.PrivateNatGatewayAssociationExists'
 
+# 不支持公网CLB。
+UNSUPPORTEDOPERATION_PUBLICCLBNOTSUPPORT = 'UnsupportedOperation.PublicClbNotSupport'
+
 # Nat网关至少存在一个弹性IP，弹性IP不能解绑。
 UNSUPPORTEDOPERATION_PUBLICIPADDRESSDISASSOCIATE = 'UnsupportedOperation.PublicIpAddressDisassociate'
 
@@ -1154,6 +1229,12 @@ UNSUPPORTEDOPERATION_TAGNOTPERMIT = 'UnsupportedOperation.TagNotPermit'
 # 不支持使用系统预留的标签键。
 UNSUPPORTEDOPERATION_TAGSYSTEMRESERVEDTAGKEY = 'UnsupportedOperation.TagSystemReservedTagKey'
 
+# 流量镜像不支持目标Clb。
+UNSUPPORTEDOPERATION_TRAFFICMIRRORNOTSUPPORTCLB = 'UnsupportedOperation.TrafficMirrorNotSupportClb'
+
+# 流量镜像源、目的不可同端。
+UNSUPPORTEDOPERATION_TRAFFICMIRRORNOTSUPPORTSAMESRCTARGET = 'UnsupportedOperation.TrafficMirrorNotSupportSameSrcTarget'
+
 # 账号ID不存在。
 UNSUPPORTEDOPERATION_UINNOTFOUND = 'UnsupportedOperation.UinNotFound'
 
